==> thux.product-2.0.0.tar.gz: thux.product-2.0.0/thux/product/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import ckeditor.fields
import thux.product.models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('store', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('vat', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Media',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('title', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('media', models.FileField(upload_to=thux.product.models.get_upload_media_path, null=True, verbose_name='media', blank=True)),
                ('url', models.URLField(null=True, verbose_name='url', blank=True)),
                ('description', ckeditor.fields.RichTextField(verbose_name='description')),
                ('creator', models.ForeignKey(related_name='product_media_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_media_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'product__name', 'id'),
                'verbose_name': 'media',
                'verbose_name_plural': 'media',
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(max_length=255, verbose_name='name', db_index=True)),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('production_code', models.CharField(db_index=True, max_length=25, verbose_name='production code', blank=True)),
                ('vendor', models.CharField(db_index=True, max_length=200, verbose_name='vendor', blank=True)),
                ('short_description', models.CharField(max_length=255, verbose_name='short description', blank=True)),
                ('full_description', ckeditor.fields.RichTextField(verbose_name='full description', blank=True)),
                ('min_supply', models.IntegerField(default=0, verbose_name='min supply')),
                ('note', models.TextField(verbose_name='note', blank=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'product',
                'verbose_name_plural': 'products',
            },
        ),
        migrations.CreateModel(
            name='ProductCategory',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('description', ckeditor.fields.RichTextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='product_productcategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_productcategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('parent', models.ForeignKey(related_name='children', blank=True, to='product.ProductCategory', null=True)),
                ('related_categories', models.ManyToManyField(to='product.ProductCategory', verbose_name='related categories')),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'product category',
                'verbose_name_plural': 'product categories',
            },
        ),
        migrations.CreateModel(
            name='UnitType',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=3, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(max_length=255, verbose_name='name', db_index=True)),
                ('creator', models.ForeignKey(related_name='product_unittype_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_unittype_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'unit',
                'verbose_name_plural': 'units',
            },
        ),
        migrations.AddField(
            model_name='product',
            name='categories',
            field=models.ManyToManyField(related_name='products', verbose_name='categories', to='product.ProductCategory'),
        ),
        migrations.AddField(
            model_name='product',
            name='creator',
            field=models.ForeignKey(related_name='product_product_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='last_modifier',
            field=models.ForeignKey(related_name='product_product_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='store_cause',
            field=models.ForeignKey(related_name='products', verbose_name='store cause', blank=True, to='store.StoreCause', null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='unit',
            field=models.ForeignKey(default=b'pz', verbose_name='unit', to='product.UnitType'),
        ),
        migrations.AddField(
            model_name='product',
            name='vat',
            field=models.ForeignKey(related_name='products', verbose_name='vat', to='vat.Vat'),
        ),
        migrations.AddField(
            model_name='media',
            name='product',
            field=models.ForeignKey(related_name='medias', verbose_name='product', to='product.Product'),
        ),
    ]

==> thux.product-2.0.2.tar.gz: thux.product-2.0.2/thux/product/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import ckeditor.fields
import thux.product.models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('store', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('vat', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Media',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('title', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('media', models.FileField(upload_to=thux.product.models.get_upload_media_path, null=True, verbose_name='media', blank=True)),
                ('url', models.URLField(null=True, verbose_name='url', blank=True)),
                ('description', ckeditor.fields.RichTextField(verbose_name='description')),
                ('creator', models.ForeignKey(related_name='product_media_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_media_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'product__name', 'id'),
                'verbose_name': 'media',
                'verbose_name_plural': 'media',
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(max_length=255, verbose_name='name', db_index=True)),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('production_code', models.CharField(db_index=True, max_length=25, verbose_name='production code', blank=True)),
                ('vendor', models.CharField(db_index=True, max_length=200, verbose_name='vendor', blank=True)),
                ('short_description', models.CharField(max_length=255, verbose_name='short description', blank=True)),
                ('full_description', ckeditor.fields.RichTextField(verbose_name='full description', blank=True)),
                ('min_supply', models.IntegerField(default=0, verbose_name='min supply')),
                ('note', models.TextField(verbose_name='note', blank=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'product',
                'verbose_name_plural': 'products',
            },
        ),
        migrations.CreateModel(
            name='ProductCategory',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='slug')),
                ('description', ckeditor.fields.RichTextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='product_productcategory_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_productcategory_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('parent', models.ForeignKey(related_name='children', blank=True, to='product.ProductCategory', null=True)),
                ('related_categories', models.ManyToManyField(to='product.ProductCategory', verbose_name='related categories')),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'product category',
                'verbose_name_plural': 'product categories',
            },
        ),
        migrations.CreateModel(
            name='UnitType',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=3, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(max_length=255, verbose_name='name', db_index=True)),
                ('creator', models.ForeignKey(related_name='product_unittype_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='product_unittype_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'unit',
                'verbose_name_plural': 'units',
            },
        ),
        migrations.AddField(
            model_name='product',
            name='categories',
            field=models.ManyToManyField(related_name='products', verbose_name='categories', to='product.ProductCategory'),
        ),
        migrations.AddField(
            model_name='product',
            name='creator',
            field=models.ForeignKey(related_name='product_product_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='last_modifier',
            field=models.ForeignKey(related_name='product_product_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='store_cause',
            field=models.ForeignKey(related_name='products', verbose_name='store cause', blank=True, to='store.StoreCause', null=True),
        ),
        migrations.AddField(
            model_name='product',
            name='unit',
            field=models.ForeignKey(default='pz', verbose_name='unit', to='product.UnitType'),
        ),
        migrations.AddField(
            model_name='product',
            name='vat',
            field=models.ForeignKey(related_name='products', verbose_name='vat', to='vat.Vat'),
        ),
        migrations.AddField(
            model_name='media',
            name='product',
            field=models.ForeignKey(related_name='medias', verbose_name='product', to='product.Product'),
        ),
    ]
